@@ -2,13 +2,15 @@
 
 """The Brubeck Message Handling system."""
 
-version = "0.3.7"
-version_info = (0, 3, 7)
+version = "0.3.9"
+version_info = (0, 3, 9)
 __all__ = ['auth',
+           'autoapi',
            'caching',
            'datamosh',
            'models',
            'mongrel2',
+           'queryset',
            'request_handling',
            'templating',
            'timekeeping']
